@@ -102,8 +102,8 @@ class Storage(driver.Base):
 #            logger.error("stream_write error:%s" % e)
 #            raise e
 
-    def list_directory(self, path=None):
-        logger.info("list_directory path:%s" % path)
+#    def list_directory(self, path=None):
+#        logger.info("list_directory path:%s" % path)
         
     def stream_write(self, path, fp):
         logger.info("stream_write path:%s" % path)
